==> klayout-0.19.3.tar.gz: klayout-0.19.3/src/layBitmapRenderer.h <==

/*

  KLayout Layout Viewer
  Copyright (C) 2006-2007 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/



#ifndef HDR_layBitmapRenderer
#define HDR_layBitmapRenderer

#include "layRenderer.h"
#include "layBitmap.h"

namespace lay
{

/**
 *  @brief A edge set and text rendering object
 *
 *  The renderer is supposed to render a set of edges to
 *  one or more bitmaps. One bitmap holds the contour
 *  information, one the fill. A third one holds the 
 *  vertex informations (dots).
 *  
 *  The intended use model is first to reserve a number of
 *  points if necessary, the fill the renderer with the
 *  edges and then render the content to the bitmaps.
 *
 *  The coordinate system of the bitmaps is 0,0..w-1,h-1
 *  with 0,0 being the lower left corner. 
 */
class BitmapRenderer 
  : public Renderer
{
public:
  /**
   *  @brief The default ctor
   */
  BitmapRenderer (unsigned int width, unsigned int height);

  /**
   *  @brief Reserve space for n edges 
   *
   *  It is strongly recommended to use this method to
   *  reserve space in advance before any insert operation for edges or boxes.
   */
  virtual void reserve_edges (size_t n);

  /**
   *  @brief Reserve space for n texts 
   *
   *  It is strongly recommended to use this method to
   *  reserve space in advance before any insert operation for texts.
   */
  virtual void reserve_texts (size_t n);

  /** 
   *  @brief Clear the content
   */
  virtual void clear ();

  /**
   *  @brief Insert edges using the provided sequence and a transform function
   *
   *  Inserts the edge sequence [from,to), transformed with f(E).
   *
   *  @param from The start of the sequence
   *  @param to The past-end iterator of the sequence
   *  @param f The function to apply before inserting the edge. It must
   *         provide a db::DEdge operator(Iter::value_type).
   */
  template <class Iter, class Func> 
  void insert_edges (Iter from, Iter to, Func f)
  {
    for (Iter e = from; e != to; ++e) {
      insert (f (*e));
    }
  }

  /** 
   *  @brief Insert a box with a transformation (because it may not be orthogonal)
   */
  virtual void insert (const db::Box &b, const db::CplxTrans &t);

  /** 
   *  @brief Insert a box with a transformation (because it may not be orthogonal)
   */
  virtual void insert (const db::DBox &b, const db::DCplxTrans &t);

  /** 
   *  @brief Insert a box 
   */
  virtual void insert (const db::DBox &b);

  /** 
   *  @brief Insert an edge 
   *
   *  The edges must be a db::DEdge type.
   */
  virtual void insert (const db::DEdge &e);

  /**
   *  @brief Insert a text
   *
   *  @box The box in which to inscribe the text (or the point at which to align if the width and height is zero)
   *  @text The text to render
   *  @font The font to use
   *  @halign The horizontal alignment
   *  @valign The vertical alignment
   *  @trans The orientation of the text
   */
  virtual void insert (const db::DBox &box, const std::string &text, db::Font font, db::HAlign halign, db::VAlign valign, db::fixpoint_trans trans);

  /**
   *  @brief Render the interior of the object to the bitmap 
   */
  virtual void render_fill (lay::CanvasPlane &bitmap);

  /**
   *  @brief Render the contour of the object to the bitmap 
   */
  virtual void render_contour (lay::CanvasPlane &bitmap);

  /**
   *  @brief Render the vertices of the object to the bitmap 
   */
  virtual void render_vertices (lay::CanvasPlane &bitmap);

  /**
   *  @brief Render the texts of the object to the bitmap
   */
  virtual void render_texts (lay::CanvasPlane &bitmap);

private:
  std::vector<lay::RenderEdge> m_edges;
  double m_xmin, m_xmax, m_ymin, m_ymax;
  bool m_ortho;
  std::vector<lay::RenderText> m_texts;
};

}

#endif

==> klayout-0.21.19.tar.gz: klayout-0.21.19/src/layBitmapRenderer.h <==

/*

  KLayout Layout Viewer
  Copyright (C) 2006-2007 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/



#ifndef HDR_layBitmapRenderer
#define HDR_layBitmapRenderer

#include "layRenderer.h"
#include "layBitmap.h"

namespace lay
{

/**
 *  @brief A edge set and text rendering object
 *
 *  The renderer is supposed to render a set of edges to
 *  one or more bitmaps. One bitmap holds the contour
 *  information, one the fill. A third one holds the 
 *  vertex informations (dots).
 *  
 *  The intended use model is first to reserve a number of
 *  points if necessary, the fill the renderer with the
 *  edges and then render the content to the bitmaps.
 *
 *  The coordinate system of the bitmaps is 0,0..w-1,h-1
 *  with 0,0 being the lower left corner. 
 */
class KLAYOUT_DLL BitmapRenderer 
  : public Renderer
{
public:
  /**
   *  @brief The default ctor
   */
  BitmapRenderer (unsigned int width, unsigned int height, double resolution);

  /**
   *  @brief Reserve space for n edges 
   *
   *  It is strongly recommended to use this method to
   *  reserve space in advance before any insert operation for edges or boxes.
   */
  virtual void reserve_edges (size_t n);

  /**
   *  @brief Reserve space for n texts 
   *
   *  It is strongly recommended to use this method to
   *  reserve space in advance before any insert operation for texts.
   */
  virtual void reserve_texts (size_t n);

  /** 
   *  @brief Clear the content
   */
  virtual void clear ();

  /**
   *  @brief Insert edges using the provided sequence and a transform function
   *
   *  Inserts the edge sequence [from,to), transformed with f(E).
   *
   *  @param from The start of the sequence
   *  @param to The past-end iterator of the sequence
   *  @param f The function to apply before inserting the edge. It must
   *         provide a db::DEdge operator(Iter::value_type).
   */
  template <class Iter, class Func> 
  void insert_edges (Iter from, Iter to, Func f)
  {
    for (Iter e = from; e != to; ++e) {
      insert (f (*e));
    }
  }

  /** 
   *  @brief Insert a box with a transformation (because it may not be orthogonal)
   */
  virtual void insert (const db::Box &b, const db::CplxTrans &t);

  /** 
   *  @brief Insert a box with a transformation (because it may not be orthogonal)
   */
  virtual void insert (const db::DBox &b, const db::DCplxTrans &t);

  /** 
   *  @brief Insert a box 
   */
  virtual void insert (const db::DBox &b);

  /** 
   *  @brief Insert an edge 
   *
   *  The edges must be a db::DEdge type.
   */
  virtual void insert (const db::DEdge &e);

  /**
   *  @brief Insert a text
   *
   *  @box The box in which to inscribe the text (or the point at which to align if the width and height is zero)
   *  @text The text to render
   *  @font The font to use
   *  @halign The horizontal alignment
   *  @valign The vertical alignment
   *  @trans The orientation of the text
   */
  virtual void insert (const db::DBox &box, const std::string &text, db::Font font, db::HAlign halign, db::VAlign valign, db::DFTrans trans);

  /**
   *  @brief Render the interior of the object to the bitmap 
   */
  virtual void render_fill (lay::CanvasPlane &bitmap);

  /**
   *  @brief Render the contour of the object to the bitmap 
   */
  virtual void render_contour (lay::CanvasPlane &bitmap);

  /**
   *  @brief Render the vertices of the object to the bitmap 
   *
   *  Mode is
   *  0 for "all vertices" (2 per edge)
   *  1 for "one vertex per edge"
   *  2 for "one vertex per every second edge"
   */
  virtual void render_vertices (lay::CanvasPlane &bitmap, int mode);

  /**
   *  @brief Render the texts of the object to the bitmap
   */
  virtual void render_texts (lay::CanvasPlane &bitmap);

private:
  std::vector<lay::RenderEdge> m_edges;
  double m_xmin, m_xmax, m_ymin, m_ymax;
  bool m_ortho;
  std::vector<lay::RenderText> m_texts;
};

}

#endif
